;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "org-mcp" "0.9"
  "MCP server for Org-mode."
  '((emacs          "27.1")
    (mcp-server-lib "0.2.0"))
  :url "https://github.com/laurynas-biveinis/org-mcp"
  :commit "70fef64ee096c13eb33389c4803c5825e146c60e"
  :revdesc "70fef64ee096"
  :keywords '("convenience" "files" "matching" "outlines")
  :authors '(("Laurynas Biveinis" . "laurynas.biveinis@gmail.com"))
  :maintainers '(("Laurynas Biveinis" . "laurynas.biveinis@gmail.com")))
